@@ -1,27 +1,43 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
-// +----------------------------------------------------------------------+
-// | PHP version 4.0                                                      |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2003 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 2.0 of the PHP license,       |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available at through the world-wide-web at                           |
-// | http://www.php.net/license/2_02.txt.                                 |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Authors: Adam Daniel <adaniel1@eesus.jnj.com>                        |
-// |          Bertrand Mansion <bmansion@mamasam.com>                     |
-// +----------------------------------------------------------------------+
-//
-// $Id: QuickForm.php,v 1.160 2005/08/04 21:15:23 avb Exp $
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
-require_once('PEAR.php');
-require_once('HTML/Common.php');
+/**
+ * Create, validate and process HTML forms
+ * 
+ * PHP versions 4 and 5
+ *
+ * LICENSE: This source file is subject to version 3.01 of the PHP license
+ * that is available through the world-wide-web at the following URI:
+ * http://www.php.net/license/3_01.txt If you did not receive a copy of
+ * the PHP License and are unable to obtain it through the web, please
+ * send a note to license@php.net so we can mail you a copy immediately.
+ *
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Adam Daniel <adaniel1@eesus.jnj.com>
+ * @author      Bertrand Mansion <bmansion@mamasam.com>
+ * @author      Alexey Borzov <avb@php.net>
+ * @copyright   2001-2011 The PHP Group
+ * @license     http://www.php.net/license/3_01.txt PHP License 3.01
+ * @version     CVS: $Id: QuickForm.php 317587 2011-10-01 07:55:53Z avb $
+ * @link        http://pear.php.net/package/HTML_QuickForm
+ */
 
+/**
+ * PEAR and PEAR_Error classes, for error handling
+ */
+require_once 'PEAR.php';
+/**
+ * Base class for all HTML classes
+ */
+require_once 'HTML/Common.php';
+
+/**
+ * Element types known to HTML_QuickForm
+ * @see HTML_QuickForm::registerElementType(), HTML_QuickForm::getRegisteredTypes(),
+ *      HTML_QuickForm::isTypeRegistered()
+ * @global array $GLOBALS['HTML_QUICKFORM_ELEMENT_TYPES']
+ */ 
 $GLOBALS['HTML_QUICKFORM_ELEMENT_TYPES'] = 
         array(
             'group'         =>array('HTML/QuickForm/group.php','HTML_QuickForm_group'),
@@ -49,6 +65,12 @@ $GLOBALS['HTML_QUICKFORM_ELEMENT_TYPES'] =
             'xbutton'       =>array('HTML/QuickForm/xbutton.php','HTML_QuickForm_xbutton')
         );
 
+/**
+ * Validation rules known to HTML_QuickForm 
+ * @see HTML_QuickForm::registerRule(), HTML_QuickForm::getRegisteredRules(),
+ *      HTML_QuickForm::isRuleRegistered()
+ * @global array $GLOBALS['_HTML_QuickForm_registered_rules']
+ */
 $GLOBALS['_HTML_QuickForm_registered_rules'] = array(
     'required'      => array('html_quickform_rule_required', 'HTML/QuickForm/Rule/Required.php'),
     'maxlength'     => array('html_quickform_rule_range',    'HTML/QuickForm/Rule/Range.php'),
@@ -67,12 +89,14 @@ $GLOBALS['_HTML_QuickForm_registered_rules'] = array(
 
 // {{{ error codes
 
-/*
- * Error codes for the QuickForm interface, which will be mapped to textual messages
- * in the QuickForm::errorMessage() function.  If you are to add a new error code, be
- * sure to add the textual messages to the QuickForm::errorMessage() function as well
- */
-
+/**#@+
+ * Error codes for HTML_QuickForm
+ *
+ * Codes are mapped to textual messages by errorMessage() method, if you add a 
+ * new code be sure to add a new message for it to errorMessage()
+ *
+ * @see HTML_QuickForm::errorMessage()
+ */ 
 define('QUICKFORM_OK',                      1);
 define('QUICKFORM_ERROR',                  -1);
 define('QUICKFORM_INVALID_RULE',           -2);
@@ -83,18 +107,22 @@ define('QUICKFORM_INVALID_ELEMENT_NAME',   -6);
 define('QUICKFORM_INVALID_PROCESS',        -7);
 define('QUICKFORM_DEPRECATED',             -8);
 define('QUICKFORM_INVALID_DATASOURCE',     -9);
+/**#@-*/
 
 // }}}
 
 /**
-* Create, validate and process HTML forms
-*
-* @author      Adam Daniel <adaniel1@eesus.jnj.com>
-* @author      Bertrand Mansion <bmansion@mamasam.com>
-* @version     2.0
-* @since       PHP 4.0.3pl1
-*/
-class HTML_QuickForm extends HTML_Common {
+ * Create, validate and process HTML forms
+ *
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Adam Daniel <adaniel1@eesus.jnj.com>
+ * @author      Bertrand Mansion <bmansion@mamasam.com>
+ * @author      Alexey Borzov <avb@php.net>
+ * @version     Release: 3.2.13
+ */
+class HTML_QuickForm extends HTML_Common
+{
     // {{{ properties
 
     /**
@@ -386,6 +414,7 @@ class HTML_QuickForm extends HTML_Common {
      * @since     3.3
      * @access    public
      * @return    void
+     * @throws    HTML_QuickForm_Error
      */
     function setDatasource(&$datasource, $defaultsFilter = null, $constantsFilter = null)
     {
@@ -413,6 +442,7 @@ class HTML_QuickForm extends HTML_Common {
      * @since     1.0
      * @access    public
      * @return    void
+     * @throws    HTML_QuickForm_Error
      */
     function setDefaults($defaultValues = null, $filter = null)
     {
@@ -452,6 +482,7 @@ class HTML_QuickForm extends HTML_Common {
      * @since     2.0
      * @access    public
      * @return    void
+     * @throws    HTML_QuickForm_Error
      */
     function setConstants($constantValues = null, $filter = null)
     {
@@ -529,7 +560,7 @@ class HTML_QuickForm extends HTML_Common {
      * @param     string     $elementType    type of element to add (text, textarea, file...)
      * @since     1.0
      * @access    public
-     * @return    object extended class of HTML_element
+     * @return    HTML_QuickForm_Element
      * @throws    HTML_QuickForm_Error
      */
     function &createElement($elementType)
@@ -550,7 +581,7 @@ class HTML_QuickForm extends HTML_Common {
      * @param     array    $args    arguments for event
      * @since     2.0
      * @access    private
-     * @return    object    a new element
+     * @return    HTML_QuickForm_Element
      * @throws    HTML_QuickForm_Error
      */
     function &_loadElement($event, $type, $args)
@@ -588,7 +619,7 @@ class HTML_QuickForm extends HTML_Common {
      *
      * @param    mixed      $element        element object or type of element to add (text, textarea, file...)
      * @since    1.0
-     * @return   object     reference to element
+     * @return   HTML_QuickForm_Element     a reference to newly added element
      * @access   public
      * @throws   HTML_QuickForm_Error
      */
@@ -642,9 +673,10 @@ class HTML_QuickForm extends HTML_Common {
     *
     * @access   public
     * @since    3.2.4
-    * @param    object  HTML_QuickForm_element  Element to insert
-    * @param    string  Name of the element before which the new one is inserted
-    * @return   object  HTML_QuickForm_element  reference to inserted element
+    * @param    HTML_QuickForm_element  Element to insert
+    * @param    string                  Name of the element before which the new
+    *                                   one is inserted
+    * @return   HTML_QuickForm_element  reference to inserted element
     * @throws   HTML_QuickForm_Error
     */
     function &insertElementBefore(&$element, $nameAfter)
@@ -709,10 +741,10 @@ class HTML_QuickForm extends HTML_Common {
      * @param    string     $separator      (optional)string to separate elements
      * @param    string     $appendName     (optional)specify whether the group name should be
      *                                      used in the form element name ex: group[element]
-     * @return   object     reference to added group of elements
+     * @return   HTML_QuickForm_group       reference to a newly added group
      * @since    2.8
      * @access   public
-     * @throws   PEAR_Error
+     * @throws   HTML_QuickForm_Error
      */
     function &addGroup($elements, $name=null, $groupLabel='', $separator=null, $appendName = true)
     {
@@ -735,7 +767,7 @@ class HTML_QuickForm extends HTML_Common {
      * @param     string     $element    Element name
      * @since     2.0
      * @access    public
-     * @return    object     reference to element
+     * @return    HTML_QuickForm_element    reference to element
      * @throws    HTML_QuickForm_Error
      */
     function &getElement($element)
@@ -810,8 +842,14 @@ class HTML_QuickForm extends HTML_Common {
             return $this->getElementValue($elementName);
 
         } elseif (false !== ($pos = strpos($elementName, '['))) {
-            $base = substr($elementName, 0, $pos);
-            $idx  = "['" . str_replace(array(']', '['), array('', "']['"), substr($elementName, $pos + 1, -1)) . "']";
+            $base = str_replace(
+                        array('\\', '\''), array('\\\\', '\\\''), 
+                        substr($elementName, 0, $pos)
+                    );
+            $idx  = "['" . str_replace(
+                        array('\\', '\'', ']', '['), array('\\\\', '\\\'', '', "']['"), 
+                        substr($elementName, $pos + 1, -1)
+                    ) . "']";
             if (isset($this->_submitValues[$base])) {
                 $value = eval("return (isset(\$this->_submitValues['{$base}']{$idx})) ? \$this->_submitValues['{$base}']{$idx} : null;");
             }
@@ -897,14 +935,18 @@ class HTML_QuickForm extends HTML_Common {
      * Set error message for a form element
      *
      * @param     string    $element    Name of form element to set error for
-     * @param     string    $message    Error message
+     * @param     string    $message    Error message, if empty then removes the current error message
      * @since     1.0       
      * @access    public
      * @return    void
      */
-    function setElementError($element,$message)
+    function setElementError($element, $message = null)
     {
-        $this->_errors[$element] = $message;
+        if (!empty($message)) {
+            $this->_errors[$element] = $message;
+        } else {
+            unset($this->_errors[$element]);
+        }
     } // end func setElementError
          
      // }}}
@@ -941,7 +983,7 @@ class HTML_QuickForm extends HTML_Common {
     function updateElementAttr($elements, $attrs)
     {
         if (is_string($elements)) {
-            $elements = split('[ ]?,[ ]?', $elements);
+            $elements = preg_split('/[ ]?,[ ]?/', $elements);
         }
         foreach (array_keys($elements) as $key) {
             if (is_object($elements[$key]) && is_a($elements[$key], 'HTML_QuickForm_element')) {
@@ -971,7 +1013,7 @@ class HTML_QuickForm extends HTML_Common {
      * @param boolean   $removeRules True if rules for this element are to be removed too                     
      * @access public
      * @since 2.0
-     * @return object HTML_QuickForm_element    a reference to the removed element
+     * @return HTML_QuickForm_element    a reference to the removed element
      * @throws HTML_QuickForm_Error
      */
     function &removeElement($elementName, $removeRules = true)
@@ -988,7 +1030,13 @@ class HTML_QuickForm extends HTML_Common {
             $this->_elementIndex[$elementName] = array_shift($this->_duplicateIndex[$elementName]);
         }
         if ($removeRules) {
-            unset($this->_rules[$elementName]);
+            $this->_required = array_diff($this->_required, array($elementName));
+            unset($this->_rules[$elementName], $this->_errors[$elementName]);
+            if ('group' == $el->getType()) {
+                foreach (array_keys($el->getElements()) as $key) {
+                    unset($this->_rules[$el->getElementName($key)]);
+                }
+            }
         }
         return $el;
     } // end func removeElement
@@ -1188,6 +1236,7 @@ class HTML_QuickForm extends HTML_Common {
      * @param    mixed     $filter        Callback, either function name or array(&$object, 'method')
      * @since    2.0
      * @access   public
+     * @throws   HTML_QuickForm_Error
      */
     function applyFilter($element, $filter)
     {
@@ -1206,7 +1255,10 @@ class HTML_QuickForm extends HTML_Common {
                     if (false === strpos($elName, '[')) {
                         $this->_submitValues[$elName] = $this->_recursiveFilter($filter, $value);
                     } else {
-                        $idx  = "['" . str_replace(array(']', '['), array('', "']['"), $elName) . "']";
+                        $idx  = "['" . str_replace(
+                                    array('\\', '\'', ']', '['), array('\\\\', '\\\'', '', "']['"), 
+                                    $elName
+                                ) . "']";
                         eval("\$this->_submitValues{$idx} = \$this->_recursiveFilter(\$filter, \$value);");
                     }
                 }
@@ -1231,7 +1283,7 @@ class HTML_QuickForm extends HTML_Common {
         if (is_array($value)) {
             $cleanValues = array();
             foreach ($value as $k => $v) {
-                $cleanValues[$k] = $this->_recursiveFilter($filter, $value[$k]);
+                $cleanValues[$k] = $this->_recursiveFilter($filter, $v);
             }
             return $cleanValues;
         } else {
@@ -1249,7 +1301,7 @@ class HTML_QuickForm extends HTML_Common {
     * The main difference is that existing keys will not be renumbered
     * if they are integers.
     *
-    * @access   puplic
+    * @access   public
     * @param    array   $a  original array
     * @param    array   $b  array which will be merged into first one
     * @return   array   merged array
@@ -1286,7 +1338,7 @@ class HTML_QuickForm extends HTML_Common {
      */
     function isTypeRegistered($type)
     {
-        return isset($GLOBALS['HTML_QUICKFORM_ELEMENT_TYPES'][$type]);
+        return isset($GLOBALS['HTML_QUICKFORM_ELEMENT_TYPES'][strtolower($type)]);
     } // end func isTypeRegistered
 
     // }}}
@@ -1451,12 +1503,13 @@ class HTML_QuickForm extends HTML_Common {
      * @access    public
      * @since     1.0
      * @return    boolean   true if no error found
+     * @throws    HTML_QuickForm_Error
      */
     function validate()
     {
         if (count($this->_rules) == 0 && count($this->_formRules) == 0 && 
             $this->isSubmitted()) {
-            return true;
+            return (0 == count($this->_errors));
         } elseif (!$this->isSubmitted()) {
             return false;
         }
@@ -1467,7 +1520,7 @@ class HTML_QuickForm extends HTML_Common {
         foreach ($this->_rules as $target => $rules) {
             $submitValue = $this->getSubmitValue($target);
 
-            foreach ($rules as $elementName => $rule) {
+            foreach ($rules as $rule) {
                 if ((isset($rule['group']) && isset($this->_errors[$rule['group']])) ||
                      isset($this->_errors[$target])) {
                     continue 2;
@@ -1479,15 +1532,26 @@ class HTML_QuickForm extends HTML_Common {
                     // Fix for bug #3501: we shouldn't validate not uploaded files, either.
                     // Unfortunately, we can't just use $element->isUploadedFile() since
                     // the element in question can be buried in group. Thus this hack.
+                    // See also bug #12014, we should only consider a file that has
+                    // status UPLOAD_ERR_NO_FILE as not uploaded, in all other cases
+                    // validation should be performed, so that e.g. 'maxfilesize' rule
+                    // will display an error if status is UPLOAD_ERR_INI_SIZE 
+                    // or UPLOAD_ERR_FORM_SIZE
                     } elseif (is_array($submitValue)) {
                         if (false === ($pos = strpos($target, '['))) {
                             $isUpload = !empty($this->_submitFiles[$target]);
                         } else {
-                            $base = substr($target, 0, $pos);
-                            $idx  = "['" . str_replace(array(']', '['), array('', "']['"), substr($target, $pos + 1, -1)) . "']";
+                            $base = str_replace(
+                                        array('\\', '\''), array('\\\\', '\\\''),
+                                        substr($target, 0, $pos) 
+                                    ); 
+                            $idx  = "['" . str_replace(
+                                        array('\\', '\'', ']', '['), array('\\\\', '\\\'', '', "']['"), 
+                                        substr($target, $pos + 1, -1)
+                                    ) . "']";
                             eval("\$isUpload = isset(\$this->_submitFiles['{$base}']['name']{$idx});");
                         }
-                        if ($isUpload && (!isset($submitValue['error']) || 0 != $submitValue['error'])) {
+                        if ($isUpload && (!isset($submitValue['error']) || UPLOAD_ERR_NO_FILE == $submitValue['error'])) {
                             continue 2;
                         }
                     }
@@ -1591,6 +1655,7 @@ class HTML_QuickForm extends HTML_Common {
      * @since    1.0
      * @access   public
      * @throws   HTML_QuickForm_Error
+     * @return   mixed     Whatever value the $callback function returns
      */
     function process($callback, $mergeFiles = true)
     {
@@ -1719,7 +1784,7 @@ class HTML_QuickForm extends HTML_Common {
                     } elseif ($dependent) {
                         $element   =  array();
                         $element[] =& $this->getElement($elementName);
-                        foreach ($rule['dependent'] as $idx => $elName) {
+                        foreach ($rule['dependent'] as $elName) {
                             $element[] =& $this->getElement($elName);
                         }
                     } else {
@@ -1814,6 +1879,7 @@ class HTML_QuickForm extends HTML_Common {
      * @param  string   Name of an element
      * @access public
      * @return mixed
+     * @throws HTML_QuickForm_Error
      */
     function exportValue($element)
     {
@@ -1903,6 +1969,7 @@ class HTML_QuickForm extends HTML_Common {
      * @access public
      * @param mixed     result code
      * @return bool     whether $value is an error
+     * @static
      */
     function isError($value)
     {
@@ -1918,6 +1985,7 @@ class HTML_QuickForm extends HTML_Common {
      * @access  public
      * @param   int     error code
      * @return  string  error message
+     * @static
      */
     function errorMessage($value)
     {
@@ -1952,6 +2020,15 @@ class HTML_QuickForm extends HTML_Common {
     // }}}
 } // end class HTML_QuickForm
 
+/**
+ * Class for errors thrown by HTML_QuickForm package
+ *
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Adam Daniel <adaniel1@eesus.jnj.com>
+ * @author      Bertrand Mansion <bmansion@mamasam.com>
+ * @version     Release: 3.2.13
+ */
 class HTML_QuickForm_Error extends PEAR_Error {
 
     // {{{ properties
@@ -1985,4 +2062,4 @@ class HTML_QuickForm_Error extends PEAR_Error {
 
     // }}}
 } // end class HTML_QuickForm_Error
-?>
\ No newline at end of file
+?>
