@@ -1,24 +1,31 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
-// +----------------------------------------------------------------------+
-// | PHP version 4.0                                                      |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2003 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 2.0 of the PHP license,       |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available at through the world-wide-web at                           |
-// | http://www.php.net/license/2_02.txt.                                 |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Author: Bertrand Mansion <bmansion@mamasam.com>                      |
-// +----------------------------------------------------------------------+
-//
-// $Id: ITStatic.php,v 1.7 2004/06/28 14:20:22 avb Exp $
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
-require_once('HTML/QuickForm/Renderer.php');
+/**
+ * A static renderer for HTML_QuickForm compatible 
+ * with HTML_Template_IT and HTML_Template_Sigma.
+ * 
+ * PHP versions 4 and 5
+ *
+ * LICENSE: This source file is subject to version 3.01 of the PHP license
+ * that is available through the world-wide-web at the following URI:
+ * http://www.php.net/license/3_01.txt If you did not receive a copy of
+ * the PHP License and are unable to obtain it through the web, please
+ * send a note to license@php.net so we can mail you a copy immediately.
+ *
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Bertrand Mansion <bmansion@mamasam.com>
+ * @copyright   2001-2011 The PHP Group
+ * @license     http://www.php.net/license/3_01.txt PHP License 3.01
+ * @version     CVS: $Id: ITStatic.php 317587 2011-10-01 07:55:53Z avb $
+ * @link        http://pear.php.net/package/HTML_QuickForm
+ */
+
+/**
+ * An abstract base class for QuickForm renderers
+ */
+require_once 'HTML/QuickForm/Renderer.php';
 
 /**
  * A static renderer for HTML_QuickForm compatible 
@@ -28,11 +35,17 @@ require_once('HTML/QuickForm/Renderer.php');
  * every elements and labels in the form to be specified by
  * placeholders at the position you want them to be displayed.
  * 
- * @author Bertrand Mansion <bmansion@mamasam.com>
- * @access public
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Bertrand Mansion <bmansion@mamasam.com>
+ * @version     Release: 3.2.13
+ * @since       3.0
  */
 class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
 {
+   /**#@+
+    * @access private
+    */
    /**
     * An HTML_Template_IT or some other API compatible Template instance
     * @var object
@@ -92,11 +105,12 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
     * @var string
     */
     var $_hidden = '';
+   /**#@-*/
 
    /**
     * Constructor
     *
-    * @param object     An HTML_Template_IT or other compatible Template object to use
+    * @param HTML_Template_IT|HTML_Template_Sigma   Template object to use
     */
     function HTML_QuickForm_Renderer_ITStatic(&$tpl)
     {
@@ -107,7 +121,7 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting a form, before processing any form elements
     *
-    * @param    object      An HTML_QuickForm object being visited
+    * @param    HTML_QuickForm  form object being visited
     * @access   public
     * @return   void
     */
@@ -126,7 +140,7 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting a form, after processing all form elements
     * 
-    * @param    object     An HTML_QuickForm object being visited
+    * @param    HTML_QuickForm  form object being visited
     * @access   public
     * @return   void
     */
@@ -156,7 +170,7 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting a header element
     *
-    * @param    object     An HTML_QuickForm_header element being visited
+    * @param    HTML_QuickForm_header   header element being visited
     * @access   public
     * @return   void
     */
@@ -175,9 +189,9 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting an element
     *
-    * @param    object     An HTML_QuickForm_element object being visited
-    * @param    bool       Whether an element is required
-    * @param    string     An error message associated with an element
+    * @param    HTML_QuickForm_element  form element being visited
+    * @param    bool                    Whether an element is required
+    * @param    string                  An error message associated with an element
     * @access   public
     * @return   void
     */
@@ -251,7 +265,7 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting a hidden element
     * 
-    * @param    object     An HTML_QuickForm_hidden object being visited
+    * @param    HTML_QuickForm_element  hidden element being visited
     * @access   public
     * @return   void
     */
@@ -269,9 +283,9 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting a group, before processing any group elements
     *
-    * @param    object     An HTML_QuickForm_group object being visited
-    * @param    bool       Whether a group is required
-    * @param    string     An error message associated with a group
+    * @param    HTML_QuickForm_group    group being visited
+    * @param    bool                    Whether a group is required
+    * @param    string                  An error message associated with a group
     * @access   public
     * @return   void
     */
@@ -322,7 +336,7 @@ class HTML_QuickForm_Renderer_ITStatic extends HTML_QuickForm_Renderer
    /**
     * Called when visiting a group, after processing all group elements
     *
-    * @param    object     An HTML_QuickForm_group object being visited
+    * @param    HTML_QuickForm_group    group being visited
     * @access   public
     * @return   void
     */
