@@ -1,45 +1,54 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
-// +----------------------------------------------------------------------+
-// | PHP Version 4                                                        |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2003 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 2.0 of the PHP license,       |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available at through the world-wide-web at                           |
-// | http://www.php.net/license/2_02.txt.                                 |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Author:  Matteo Di Giovinazzo <matteodg@infinito.it>                 |
-// |                                                                      |
-// | For the JavaScript code thanks to Martin Honnen and                  |
-// | Nicholas C. Zakas                                                    |
-// | See:                                                                 |
-// |      http://www.faqts.com/knowledge_base/view.phtml/aid/13562        |
-// | and                                                                  |
-// |      http://www.sitepoint.com/article/1220                           |
-// +----------------------------------------------------------------------+
-//
-// $Id: autocomplete.php,v 1.6 2005/08/05 16:33:56 avb Exp $
-
-
-require_once("HTML/QuickForm/text.php");
-
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
 
 /**
- * Class to dynamically create an HTML input text element that
- * at every keypressed javascript event, check in an array of options
- * if there's a match and autocomplete the text in case of match.
+ * HTML class for an autocomplete element
  *
- * Ex:
+ * PHP versions 4 and 5
+ *
+ * LICENSE: This source file is subject to version 3.01 of the PHP license
+ * that is available through the world-wide-web at the following URI:
+ * http://www.php.net/license/3_01.txt If you did not receive a copy of
+ * the PHP License and are unable to obtain it through the web, please
+ * send a note to license@php.net so we can mail you a copy immediately.
+ *
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Matteo Di Giovinazzo <matteodg@infinito.it>
+ * @copyright   2001-2011 The PHP Group
+ * @license     http://www.php.net/license/3_01.txt PHP License 3.01
+ * @version     CVS: $Id: autocomplete.php 317587 2011-10-01 07:55:53Z avb $
+ * @link        http://pear.php.net/package/HTML_QuickForm
+ */
+
+/**
+ * HTML class for a text field
+ */
+require_once 'HTML/QuickForm/text.php';
+
+/**
+ * HTML class for an autocomplete element
+ *
+ * Creates an HTML input text element that
+ * at every keypressed javascript event checks in an array of options
+ * if there's a match and autocompletes the text in case of match.
+ *
+ * For the JavaScript code thanks to Martin Honnen and Nicholas C. Zakas
+ * See {@link http://www.faqts.com/knowledge_base/view.phtml/aid/13562} and
+ * {@link http://www.sitepoint.com/article/1220}
+ *
+ * Example:
+ * <code>
  * $autocomplete =& $form->addElement('autocomplete', 'fruit', 'Favourite fruit:');
  * $options = array("Apple", "Orange", "Pear", "Strawberry");
  * $autocomplete->setOptions($options);
+ * </code>
  *
- * @author       Matteo Di Giovinazzo <matteodg@infinito.it>
+ * @category    HTML
+ * @package     HTML_QuickForm
+ * @author      Matteo Di Giovinazzo <matteodg@infinito.it>
+ * @version     Release: 3.2.13
+ * @since       3.2
  */
 class HTML_QuickForm_autocomplete extends HTML_QuickForm_text
 {
@@ -115,7 +124,7 @@ class HTML_QuickForm_autocomplete extends HTML_QuickForm_text
         $arrayName = str_replace(array('[', ']'), array('__', ''), $this->getName()) . '_values';
 
         $this->updateAttributes(array(
-            'onkeypress' => 'return autocomplete(this, event, ' . $arrayName . ');'
+            'onkeypress' => 'return window.autocomplete(this, event, ' . $arrayName . ');'
         ));
         if ($this->_flagFrozen) {
             $js = '';
@@ -208,7 +217,7 @@ function autocomplete(textbox, event, values) {
                 replaceSelection(textbox, c);
                 sMatch = autocompleteMatch(textbox.value, values);
                 var len = textbox.value.length;
-				
+
                 if (sMatch != null) {
                     textbox.value = sMatch;
                     setSelectionRange(textbox, len, textbox.value.length);
